
# This file was automatically generated by Dist::Zilla::Plugin::ModuleBuild v5.020.
use strict;
use warnings;

use Module::Build 0.28;


my %module_build_args = (
  "build_requires" => {
    "Module::Build" => "0.28"
  },
  "configure_requires" => {
    "Module::Build" => "0.28"
  },
  "dist_abstract" => "a high-level bot framework for interacting with MediaWiki wikis",
  "dist_author" => [
    "Dan Collins <dcollins\@cpan.org>",
    "Mike.lifeguard <lifeguard\@cpan.org>",
    "Alex Rowe <alex.d.rowe\@gmail.com>",
    "Oleg Alexandrov <oleg.alexandrov\@gmail.com>",
    "jmax.code <jmax.code\@gmail.com>",
    "Stefan Petrea <stefan.petrea\@gmail.com>",
    "kc2aei <kc2aei\@gmail.com>",
    "bosborne\@alum.mit.edu",
    "Brian Obio <brianobio\@gmail.com>",
    "patch and bug report contributors"
  ],
  "dist_name" => "MediaWiki-Bot",
  "dist_version" => "5.006002",
  "license" => "gpl",
  "module_name" => "MediaWiki::Bot",
  "recommends" => {},
  "recursive_test_files" => 1,
  "requires" => {
    "Carp" => 0,
    "Constant::Generate" => 0,
    "Digest::MD5" => "2.39",
    "Encode" => 0,
    "Exporter" => 0,
    "File::Basename" => 0,
    "HTML::Entities" => "3.28",
    "LWP::Protocol::https" => "0.57",
    "List::Util" => 0,
    "MediaWiki::API" => "0.36",
    "Module::Pluggable" => 0,
    "perl" => "5.008",
    "strict" => 0,
    "warnings" => 0
  },
  "script_files" => [],
  "test_requires" => {
    "File::Spec" => 0,
    "IO::Handle" => 0,
    "IPC::Open3" => 0,
    "List::MoreUtils" => 0,
    "Test::Is" => 0,
    "Test::More" => "0.96",
    "Test::RequiresInternet" => 0,
    "Test::Warn" => 0,
    "perl" => "5.008",
    "utf8" => 0
  }
);


my %fallback_build_requires = (
  "File::Spec" => 0,
  "IO::Handle" => 0,
  "IPC::Open3" => 0,
  "List::MoreUtils" => 0,
  "Module::Build" => "0.28",
  "Test::Is" => 0,
  "Test::More" => "0.96",
  "Test::RequiresInternet" => 0,
  "Test::Warn" => 0,
  "perl" => "5.008",
  "utf8" => 0
);


unless ( eval { Module::Build->VERSION(0.4004) } ) {
  delete $module_build_args{test_requires};
  $module_build_args{build_requires} = \%fallback_build_requires;
}

my $build = Module::Build->new(%module_build_args);

$build->create_build_script;
